==> igniteui-react-charts-18.7.2.tgz: package/esm2015/lib/igr-radial-pie-series.js <==
import { LegendEmptyValuesMode_$type } from "igniteui-react-core";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialPieSeries } from "./RadialPieSeries";
import { ensureEnum, toPoint, fromRect } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent radial pie series.
 * Compare values across categories by using radial pie slices.
*/
export class IgrRadialPieSeries extends IgrAnchoredRadialSeries {
    createImplementation() {
        return new RadialPieSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows a pie shape.
    */
    get isPie() {
        return this.i.fl;
    }
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred() {
        return this.i.fj;
    }
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX() {
        return this.i.adj;
    }
    set radiusX(v) {
        this.i.adj = +v;
    }
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY() {
        return this.i.adk;
    }
    set radiusY(v) {
        this.i.adk = +v;
    }
    /**
     * Gets or sets the property name that contains the legend labels.
    */
    get legendLabelMemberPath() {
        return this.i.ado;
    }
    set legendLabelMemberPath(v) {
        this.i.ado = v;
    }
    /**
     * Determines display mode for zero values in the legend.
    */
    get legendEmptyValuesMode() {
        return this.i.ade;
    }
    set legendEmptyValuesMode(v) {
        this.i.ade = ensureEnum(LegendEmptyValuesMode_$type, v);
    }
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan() {
        let iv = this.i.iu();
        return (iv);
    }
    getSeriesValueBoundingBox(world) {
        let iv = this.i.wh(toPoint(world));
        return fromRect(iv);
    }
}

==> igniteui-react-charts-19.0.0.tgz: package/esm2015/lib/igr-radial-pie-series.js <==
import { LegendEmptyValuesMode_$type } from "igniteui-react-core";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialPieSeries } from "./RadialPieSeries";
import { ensureEnum, toPoint, fromRect } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent radial pie series.
 * Compare values across categories by using radial pie slices.
*/
export class IgrRadialPieSeries extends IgrAnchoredRadialSeries {
    createImplementation() {
        return new RadialPieSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows a pie shape.
    */
    get isPie() {
        return this.i.fo;
    }
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred() {
        return this.i.fm;
    }
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX() {
        return this.i.ady;
    }
    set radiusX(v) {
        this.i.ady = +v;
    }
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY() {
        return this.i.adz;
    }
    set radiusY(v) {
        this.i.adz = +v;
    }
    /**
     * Gets or sets the property name that contains the legend labels.
    */
    get legendLabelMemberPath() {
        return this.i.ad3;
    }
    set legendLabelMemberPath(v) {
        this.i.ad3 = v;
    }
    /**
     * Determines display mode for zero values in the legend.
    */
    get legendEmptyValuesMode() {
        return this.i.adt;
    }
    set legendEmptyValuesMode(v) {
        this.i.adt = ensureEnum(LegendEmptyValuesMode_$type, v);
    }
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan() {
        let iv = this.i.ix();
        return (iv);
    }
    getSeriesValueBoundingBox(world) {
        let iv = this.i.ws(toPoint(world));
        return fromRect(iv);
    }
}
